.. currentmodule:: sardana.macroserver.mstypemanager

:mod:`~sardana.macroserver.mstypemanager`
===========================================

.. automodule:: sardana.macroserver.mstypemanager

.. rubric:: Functions

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`TypeManager`

TypeManager
--------------------

.. autoclass:: TypeManager
    :show-inheritance:
